/* Program reads raw CPS data and computes

1.  education by industry to be merged with inequality

2.  industry inequality to be merged with computer usage and
	education files

3.  within-between figures for Tables 1 and 2 of the paper */


libname a 'd:\research\FedReview';

data a.samp;
set a.rawcps;
if age >= 18 and age <= 65;
if earnwke > 0; /* must have positive earnings */
run;

/* private, non-self-employed workers */
data a.samp;
set a.samp;
if year < 1994 and class > 1 then delete;
if year > 1993 and class94 < 4 then delete;
if year > 1993 and class94 > 5 then delete;
run;

/* create basic covariates */
data a.samp;
set a.samp;
married = 0;
female = 0;
nonwhite = 0;
urban = 0;
nohs = 0;
somehs = 0;
hs = 0;
somecoll = 0;
coll = 0;
div1 = 0;
div2 = 0;
div3 = 0;
div4 = 0;
div5 = 0;
div6 = 0;
div7 = 0;
div8 = 0;
union = 0;
run;
data a.samp;
set a.samp;
if marital < 4 then married = 1;
if sex = 2 then female = 1;
if race > 1 then nonwhite = 1;
if smsastat = 1 then urban = 1;
if smsastat = . then urban = .;
if unionmme = 1 then union = 1;
run;
data a.samp;
set a.samp;
if year < 1992 and gradeat < 9 then nohs = 1;
if year < 1992 and gradeat = 9 and gradecp = 2 then nohs = 1;
if year < 1992 and gradeat >= 9 and gradeat < 12 then somehs = 1;
if year < 1992 and gradeat = 12 and gradecp = 2 then somehs = 1;
if year < 1992 and gradeat = 12 and gradecp = 1 then hs = 1;
if year < 1992 and gradeat > 12 and gradeat < 16 then somecoll = 1;
if year < 1992 and gradeat = 16 and gradecp = 2 then somecoll = 1;
if year < 1992 and gradeat >= 16 then coll = 1;
if year > 1991 and grade92 >= 31 and grade92 <= 34 then nohs = 1;
if year > 1991 and grade92 >= 35 and grade92 <= 38 then somehs = 1;
if year > 1991 and grade92 = 39 then hs = 1;
if year > 1991 and grade92 >= 40 and grade92 <= 42 then somecoll = 1;
if year > 1991 and grade92 >= 43 then coll = 1;
run;
data a.samp;
set a.samp;
if state >= 11 and state <= 16 then div1 = 1;
if state >= 21 and state <= 23 then div2 = 1;
if state >= 31 and state <= 35 then div3 = 1;
if state >= 41 and state <= 47 then div4 = 1;
if state >= 51 and state <= 59 then div5 = 1;
if state >= 61 and state <= 64 then div6 = 1;
if state >= 71 and state <= 74 then div7 = 1;
if state >= 81 and state <= 88 then div8 = 1;
run;

/* PCE Values to make wages real (2000 dollars) */

data a.samp;
set a.samp;
if year = 1983 then priceadj = 1.60164;
if year = 1984 then priceadj = 1.543323;
if year = 1985 then priceadj = 1.493976;
if year = 1986 then priceadj = 1.45839;
if year = 1987 then priceadj = 1.409508;
if year = 1988 then priceadj = 1.355831;
if year = 1989 then priceadj = 1.29917;
if year = 1990 then priceadj = 1.242271;
if year = 1991 then priceadj = 1.198775;
if year = 1992 then priceadj = 1.165168;
if year = 1993 then priceadj = 1.1389;
if year = 1994 then priceadj = 1.115405;
if year = 1995 then priceadj = 1.09198;
if year = 1996 then priceadj = 1.068984;
if year = 1997 then priceadj = 1.051259;
if year = 1998 then priceadj = 1.041905;
if year = 1999 then priceadj = 1.024855;
if year = 2000 then priceadj = 1;
if year = 2001 then priceadj = 0.979489;
if year = 2002 then priceadj = 0.96574;
run;

/* compute real hourly wages */

data a.samp;
set a.samp;
rhrwage = priceadj*earnwke/uhourse;
run;

/* estimation of mean above topcodes */
/* note: this follows Card and DiNardo (JOLE 2002) */

data a.samp;
set a.samp;
if year <= 1988 and earnwke = 999 then rhrwage = 1.4*rhrwage;
if year >= 1989 and year <= 1997 
	and earnwke >= 1923 then rhrwage = 1.4*rhrwage;
if year >= 1998 and earnwke >= 2884 then rhrwage = 1.4*rhrwage;
run;

/* create consistent 3-digit industry codes */

data a.samp;
set a.samp;
IF YEAR LE 1991 THEN DO ;
    consind = ind80 ;
    IF consind EQ 891 THEN consind = 730; * COMBINE SCIENTIFIC RESEARCH;
END ; 

IF YEAR GE 1992 THEN DO ;
    IF ind80 LE  11 THEN consind = ind80 ; * NO CHANGE ;
    IF ind80 EQ  12 THEN consind =  20 ;* INCLUDE VET SERV IN AG SERV NEC;
    IF ind80 EQ  20 THEN consind =  21 ;* CODE CHANGE ;
    IF ind80 EQ  30 THEN consind =  20 ;* CODE CHANGE ;
    IF ind80 EQ  31 THEN consind =  30 ;* CODE CHANGE ;
    IF ind80 EQ  32 THEN consind =  31 ;* CODE CHANGE ;             
    IF ind80 GE  40 AND ind80 LE 449 THEN consind = ind80;* NO CHANGE ;
    IF ind80 EQ 450 THEN consind = 460 ;* CODE CHANGE ;
    IF ind80 EQ 451 THEN consind = 461 ;* CODE CHANGE ;
    IF ind80 EQ 452 THEN consind = 462 ;* CODE CHANGE ;
    IF ind80 GE 453 AND ind80 LE 622 THEN consind = ind80 ;* NO CHANGE ;
    IF ind80 EQ 623 THEN consind = 630 ;* CODE CHANGE ;
    IF ind80 EQ 630 THEN consind = 631 ;* CODE CHANGE ;
    IF ind80 EQ 631 THEN consind = 632 ;* CODE CHANGE ;
    IF ind80 EQ 632 THEN consind = 640 ;* INCLUDE APPL. IN APPL AND ETC.;
    IF ind80 EQ 633 THEN consind = 640 ;* INCLUDE RADIO IN APPL AND ETC ;
    IF ind80 EQ 640 THEN consind = 640 ;* INCLUDE MUSIC IN APPL AND ETC.;
    IF ind80 GE 641 AND ind80 LE 660 THEN consind = ind80;* NO CHANGE ;
    IF ind80 EQ 661 THEN consind = 682 ;* INCLUDE GIFT IN MISC STORES ;
    IF ind80 EQ 662 THEN consind = 661 ;* CODE CHANGE ;
    IF ind80 EQ 663 THEN consind = 662 ;* CODE CHANGE ;
    IF ind80 GE 670 AND ind80 LE 731 THEN consind = ind80;* NO CHANGE ;
    IF ind80 EQ 732 THEN consind = 740 ;* CODE CHANGE ;
    IF ind80 EQ 740 THEN consind = 741 ;* CODE CHANGE ;
    IF ind80 EQ 741 THEN consind = 742 ;* CODE CHANGE ;
    IF ind80 EQ 742 THEN consind = 750 ;* INCLUDE AUTO RENTAL IN AUTO SERV;
    IF ind80 GE 750 AND ind80 LE 800 THEN consind = ind80;
    IF ind80 EQ 801 THEN consind = 800 ;* VIDEO RENTAL IN THEATERS ;
    IF ind80 EQ 802 THEN consind = 801 ;* CODE CHANGE ;
    IF ind80 EQ 810 THEN consind = 802 ;* CODE CHANGE ;
    IF ind80 GE 812 AND ind80 LE 862 THEN consind = ind80 ;* NO CHANGE ;
    IF ind80 EQ 863 THEN consind = 862 ;* COMBINE CHILD CARE CATEGORIES ;
    IF ind80 GE 870 AND ind80 LE 872 THEN consind = ind80;* NO CHANGE ;
    IF ind80 EQ 873 THEN consind = 881 ;* INCLUDE LABOR UNIONS IN MEM ORG;
    IF ind80 GE 880 AND ind80 LE 890 THEN consind = ind80;* NO CHANGE ;
    IF ind80 EQ 891 THEN consind = 730; * MOVE SCIENTIFIC RESEARCH;
    IF ind80 EQ 892 THEN consind = 732 ;* CODE CHANGE ;
    IF ind80 EQ 893 THEN consind = 892 ;* CODE CHANGE ;
    IF ind80 GE 894 THEN consind = ind80; *NO CHANGE ; 
END ;  
run;

data a.samp;
set a.samp;
if nohs = 1 then educcat = 1;
if somehs = 1 then educcat = 2;
if hs = 1 then educcat = 3;
if somecoll = 1 then educcat = 4;
if coll = 1 then educcat = 5;
run;

/* Create potential experience using Park (1994) */

data a.samp;
set a.samp;
if year <= 1991 then do;
	edyrs = gradeat;
end;
run;
data a.samp;
set a.samp;
if year <= 1991 and gradecp = 2 then edyrs = edyrs - 1;
run;
data a.samp;
set a.samp;
if year <= 1991 and edyrs < 0 then edyrs = 0;
run;

data a.samp;
set a.samp;
educ99 = grade92;
run;

data a.samp;
set a.samp;
if year >= 1992 then do;

if educ99 = 31 
	and female = 0 and nonwhite = 0 then edyrs = 0.32;
if educ99 = 32 
	and female = 0 and nonwhite = 0 then edyrs = 3.19;
if educ99 >= 33 and educ99 <= 34 
	and female = 0 and nonwhite = 0 then edyrs = 7.24;
if educ99 = 35 
	and female = 0 and nonwhite = 0 then edyrs = 8.97;
if educ99 = 36 
	and female = 0 and nonwhite = 0 then edyrs = 9.92;
if educ99 = 37 
	and female = 0 and nonwhite = 0 then edyrs = 10.86;
if educ99 = 38 
	and female = 0 and nonwhite = 0 then edyrs = 11.58;
if educ99 = 39 
	and female = 0 and nonwhite = 0 then edyrs = 11.99;
if educ99 = 40 
	and female = 0 and nonwhite = 0 then edyrs = 13.48;
if educ99 >= 41 and educ99 <= 42 
	and female = 0 and nonwhite = 0 then edyrs = 14.23;
if educ99 = 43 
	and female = 0 and nonwhite = 0 then edyrs = 16.17;
if educ99 = 44 
	and female = 0 and nonwhite = 0 then edyrs = 17.68;
if educ99 = 45 
	and female = 0 and nonwhite = 0 then edyrs = 17.71;
if educ99 = 46 
	and female = 0 and nonwhite = 0 then edyrs = 17.83;

if educ99 = 31 
	and female = 0 and nonwhite = 1 then edyrs = 0.92;
if educ99 = 32 
	and female = 0 and nonwhite = 1 then edyrs = 3.28;
if educ99 >= 33 and educ99 <= 34
	and female = 0 and nonwhite = 1 then edyrs = 7.04;
if educ99 = 35 
	and female = 0 and nonwhite = 1 then edyrs = 9.02;
if educ99 = 36 
	and female = 0 and nonwhite = 1 then edyrs = 9.91;
if educ99 = 37 
	and female = 0 and nonwhite = 1 then edyrs = 10.9;
if educ99 = 38 
	and female = 0 and nonwhite = 1 then edyrs = 11.41;
if educ99 = 39 
	and female = 0 and nonwhite = 1 then edyrs = 11.98;
if educ99 = 40 
	and female = 0 and nonwhite = 1 then edyrs = 13.57;
if educ99 >= 41 and educ99 <= 42 
	and female = 0 and nonwhite = 1 then edyrs = 14.33;
if educ99 = 43 
	and female = 0 and nonwhite = 1 then edyrs = 16.13;
if educ99 = 44 
	and female = 0 and nonwhite = 1 then edyrs = 17.51;
if educ99 = 45 
	and female = 0 and nonwhite = 1 then edyrs = 17.83;
if educ99 = 46 
	and female = 0 and nonwhite = 1 then edyrs = 18;

if educ99 = 31 
	and female = 1 and nonwhite = 0 then edyrs = 0.62;
if educ99 = 32 
	and female = 1 and nonwhite = 0 then edyrs = 3.15;
if educ99 >= 33 and educ99 <= 34
	and female = 1 and nonwhite = 0 then edyrs = 7.23;
if educ99 = 35 
	and female = 1 and nonwhite = 0 then edyrs = 8.99;
if educ99 = 36 
	and female = 1 and nonwhite = 0 then edyrs = 9.95;
if educ99 = 37 
	and female = 1 and nonwhite = 0 then edyrs = 10.87;
if educ99 = 38 
	and female = 1 and nonwhite = 0 then edyrs = 11.73;
if educ99 = 39 
	and female = 1 and nonwhite = 0 then edyrs = 12;
if educ99 = 40 
	and female = 1 and nonwhite = 0 then edyrs = 13.35;
if educ99 >= 41 and educ99 <= 42 
	and female = 1 and nonwhite = 0 then edyrs = 14.22;
if educ99 = 43 
	and female = 1 and nonwhite = 0 then edyrs = 16.15;
if educ99 = 44 
	and female = 1 and nonwhite = 0 then edyrs = 17.64;
if educ99 = 45 
	and female = 1 and nonwhite = 0 then edyrs = 17;
if educ99 = 46 
	and female = 1 and nonwhite = 0 then edyrs = 17.76;

if educ99 = 31 
	and female = 1 and nonwhite = 1 then edyrs = 0;
if educ99 = 32 
	and female = 1 and nonwhite = 1 then edyrs = 2.9;
if educ99 >= 33 and educ99 <= 34
	and female = 1 and nonwhite = 1 then edyrs = 7.03;
if educ99 = 35 
	and female = 1 and nonwhite = 1 then edyrs = 9.05;
if educ99 = 36 
	and female = 1 and nonwhite = 1 then edyrs = 9.99;
if educ99 = 37 
	and female = 1 and nonwhite = 1 then edyrs = 10.85;
if educ99 = 38 
	and female = 1 and nonwhite = 1 then edyrs = 11.64;
if educ99 = 39 
	and female = 1 and nonwhite = 1 then edyrs = 12;
if educ99 = 40 
	and female = 1 and nonwhite = 1 then edyrs = 13.43;
if educ99 >= 41 and educ99 <= 42 
	and female = 1 and nonwhite = 1 then edyrs = 14.33;
if educ99 = 43 
	and female = 1 and nonwhite = 1 then edyrs = 16.04;
if educ99 = 44 
	and female = 1 and nonwhite = 1 then edyrs = 17.69;
if educ99 = 45 
	and female = 1 and nonwhite = 1 then edyrs = 17.4;
if educ99 = 46 
	and female = 1 and nonwhite = 1 then edyrs = 18;
end;
run;
data a.samp;
set a.samp;
exper = max(age-edyrs-6, 0);
run;
data a.samp;
set a.samp;
exper2 = exper**2;
exper3 = exper**3;
exper4 = exper**4;
run;

/* PART 1: CHARACTERISTICS OF INDUSTRIES */
/* use earnwt for all calculations, not just inequality
	figures below */

proc sort data=a.samp;
by year consind;
run;
proc univariate data=a.samp noprint;
by year consind;
var nohs somehs hs somecoll coll;
output out = a.int1a mean = nohs somehs hs somecoll coll;
weight earnwt;
run;
data a.samp;
set a.samp;
hrnhs = nohs*uhourse;
hrshs = somehs*uhourse;
hrhs = hs*uhourse;
hrscoll = somecoll*uhourse;
hrcoll = coll*uhourse;
run;
proc sort data=a.samp;
by year consind;
run;
proc univariate data=a.samp noprint;
by year consind;
var hrnhs hrshs hrhs hrscoll hrcoll uhourse;
output out = a.int1b sum = hrnhs hrshs hrhs hrscoll hrcoll hrtot;
weight earnwt;
run;
proc univariate data=a.samp noprint;
by year consind;
var nohs;
output out = a.int1c n = indobs;
run;

proc sort data=a.int1a;
by year consind;
run;
proc sort data=a.int1b;
by year consind;
run;
proc sort data=a.int1c;
by year consind;
run;

data a.indeduc;
merge a.int1a a.int1b a.int1c;
by year consind;
run;


/* PART 2: INEQUALITY CALCULATIONS */

/* sample selection - white males, full-time, wages truncated
	below by 2.6 and above by 150 */

data a.samp;
set a.samp;
if female = 0 and nonwhite = 0;
if uhourse > 29; /* full time workers */
if rhrwage >= 2.6 and rhrwage <= 150;
run;

data a.samp;
set a.samp;
lhrwage = log(rhrwage);
run;

/* overall inequality measures */

proc sort data=a.samp;
by year consind;
run;
proc univariate data=a.samp noprint vardef = weight;
by year consind;
freq earnwt;
var lhrwage;
output out = a.int1 p90 = p90 q3 = p75 median = p50
	q1 = p25 p10 = p10;
run;
proc univariate data=a.samp noprint vardef = weight;
by year consind;
weight earnwt;
var lhrwage;
output out = a.int2 mean = lhrwage var = vlhrwage;
run;
proc univariate data=a.samp noprint vardef = weight;
by year consind;
var lhrwage;
output out = a.int3 n=obs;
run;
proc sort data=a.int1;
by year consind;
run;
proc sort data=a.int2;
by year consind;
run;
proc sort data=a.int3;
by year consind;
run;
data a.junk1;
merge a.int1 a.int2 a.int3;
by year consind;
run;

proc sort data=a.samp;
by year consind educcat;
run;
proc univariate data=a.samp noprint vardef = weight;
by year consind educcat;
freq earnwt;
var lhrwage;
output out = a.int1a p90 = p90 q3 = p75 median = p50
	q1 = p25 p10 = p10;
run;
proc univariate data=a.samp noprint vardef = weight;
by year consind educcat;
weight earnwt;
var lhrwage;
output out = a.int2a mean = lhrwage var = vlhrwage;
run;
proc univariate data=a.samp noprint vardef = weight;
by year consind educcat;
var lhrwage;
output out = a.int3a n=obs;
run;
proc sort data=a.int1a;
by year consind educcat;
run;
proc sort data=a.int2a;
by year consind educcat;
run;
proc sort data=a.int3a;
by year consind educcat;
run;
data a.junk2;
merge a.int1a a.int2a a.int3a;
by year consind educcat;
run;

data a.indineq;
set a.junk1 a.junk2;
run;


/* residual inequality measures */

data a.samp;
set a.samp;
edyr1 = nohs*edyrs;
edyr2 = somehs*edyrs;
edyr4 = somecoll*edyrs;
edyr5 = coll*edyrs;
run;

proc sort data=a.samp;
by year;
run;
proc reg data=a.samp noprint;
model lhrwage = nohs somehs somecoll coll exper exper2 exper3 exper4
	edyrs edyr1 edyr2 edyr4 edyr5
	married urban union div1-div8;
output out = a.sampr
	r = lhwres;
weight earnwt;
by year;
run;
data a.sampr;
set a.sampr;
drop lhrwage;
run;
data a.sampr;
set a.sampr;
rename lhwres = lhrwage;
run;

proc sort data=a.sampr;
by year consind;
run;
proc univariate data=a.sampr noprint vardef = weight;
by year consind;
freq earnwt;
var lhrwage;
output out = a.int1 p90 = p90 q3 = p75 median = p50
	q1 = p25 p10 = p10;
run;
proc univariate data=a.sampr noprint vardef = weight;
by year consind;
weight earnwt;
var lhrwage;
output out = a.int2 mean = lhrwage var = vlhrwage;
run;
proc univariate data=a.sampr noprint vardef = weight;
by year consind;
var lhrwage;
output out = a.int3 n=obs;
run;
proc sort data=a.int1;
by year consind;
run;
proc sort data=a.int2;
by year consind;
run;
proc sort data=a.int3;
by year consind;
run;
data a.indineqr;
merge a.int1 a.int2 a.int3;
by year consind;
run;


/* Within-between analysis */

proc sort data=a.samp;
by year;
run;
proc univariate data = a.samp noprint vardef = weight;
var lhrwage;
by year;
output out = a.int1
	var = totvar mean = totmean;
weight earnwt;
run;
proc univariate data = a.samp noprint;
var earnwt;
by year;
output out = a.int1a
	sum = obs;
run;

data a.int1;
set a.int1;
keep year totvar totmean;
run;
data a.int1a;
set a.int1a;
keep year obs;
run;

proc sort data=a.samp;
by year consind;
run;

proc univariate data = a.samp noprint;
var lhrwage;
by year consind;
output out = a.int2
	mean = cindmean;
weight earnwt;
run;
data a.int2;
set a.int2;
keep year consind cindmean;
run;

proc sort data=a.samp;
by year;
run;
proc sort data=a.int1;
by year;
run;
data a.samp;
merge a.samp a.int1;
by year;
run;

proc sort data=a.samp;
by year consind;
run;
proc sort data=a.int2;
by year consind;
run;
data a.samp;
merge a.samp a.int2;
by year consind;
run;

data a.samp;
set a.samp;
wthnind = (lhrwage - cindmean)**2;
btwnind = (cindmean - totmean)**2;
run;
proc sort data=a.samp;
by year;
run;
proc means data=a.samp noprint;
var wthnind btwnind;
by year;
output out = a.wtbt sum=;
weight earnwt;
run;
data a.wtbt;
set a.wtbt;
keep year wthnind wthnocc btwnind btwnocc;
run;
proc sort data=a.wtbt;
by year;
run;
proc sort data=a.int1;
by year;
run;
data a.wtbt;
merge a.wtbt a.int1;
by year;
run;
proc sort data=a.wtbt;
by year;
run;
proc sort data=a.int1a;
by year;
run;
data a.wtbt;
merge a.wtbt a.int1a;
by year;
run;

/* residual inequality decomposition */

proc sort data=a.sampr;
by year;
run;
data a.sampr;
set a.sampr;
if lhrwage NE .;
run;

proc univariate data = a.sampr noprint vardef = weight;
var lhrwage;
by year;
output out = a.int1
	var = totvar mean = totmean;
weight earnwt;
run;
proc univariate data = a.sampr noprint;
var earnwt;
by year;
output out = a.int1a
	sum = obs;
run;

data a.int1;
set a.int1;
keep year totvar totmean;
run;
data a.int1a;
set a.int1a;
keep year obs;
run;

proc sort data=a.sampr;
by year consind;
run;

proc univariate data = a.sampr noprint;
var lhrwage;
by year consind;
output out = a.int2
	mean = cindmean;
weight earnwt;
run;
data a.int2;
set a.int2;
keep year consind cindmean;
run;

proc sort data=a.sampr;
by year;
run;
proc sort data=a.int1;
by year;
run;
data a.sampr;
merge a.sampr a.int1;
by year;
run;

proc sort data=a.sampr;
by year consind;
run;
proc sort data=a.int2;
by year consind;
run;
data a.sampr;
merge a.sampr a.int2;
by year consind;
run;

data a.sampr;
set a.sampr;
wthnind = (lhrwage - cindmean)**2;
btwnind = (cindmean - totmean)**2;
run;
proc sort data=a.sampr;
by year;
run;
proc means data=a.sampr noprint;
var wthnind btwnind;
by year;
output out = a.wtbtres sum=;
weight earnwt;
run;
data a.wtbtres;
set a.wtbtres;
keep year wthnind btwnind;
run;
proc sort data=a.wtbtres;
by year;
run;
proc sort data=a.int1;
by year;
run;
data a.wtbtres;
merge a.wtbtres a.int1;
by year;
run;
proc sort data=a.wtbtres;
by year;
run;
proc sort data=a.int1a;
by year;
run;
data a.wtbtres;
merge a.wtbtres a.int1a;
by year;
run;

